@@ -2,9 +2,9 @@ use strict;
 use warnings;
 package Dist::Zilla::Plugin::OnlyCorePrereqs;
 {
-  $Dist::Zilla::Plugin::OnlyCorePrereqs::VERSION = '0.011';
+  $Dist::Zilla::Plugin::OnlyCorePrereqs::VERSION = '0.012';
 }
-# git description: v0.010-TRIAL-4-gc054af3
+# git description: v0.011-4-g88923ba
 
 BEGIN {
   $Dist::Zilla::Plugin::OnlyCorePrereqs::AUTHORITY = 'cpan:ETHER';
@@ -25,7 +25,7 @@ use namespace::autoclean;
 has phases => (
     isa => 'ArrayRef[Str]',
     lazy => 1,
-    default => sub { [ qw(runtime test) ] },
+    default => sub { [ qw(configure build runtime test) ] },
     traits => ['Array'],
     handles => { phases => 'elements' },
 );
@@ -51,8 +51,16 @@ has check_dual_life_versions => (
     default => 1,
 );
 
-sub mvp_multivalue_args { qw(phases) }
-sub mvp_aliases { { phase => 'phases' } }
+has skips => (
+    isa => 'ArrayRef[Str]',
+    traits => ['Array'],
+    handles => { skip_module => 'grep' },
+    lazy => 1,
+    default => sub { [] },
+);
+
+sub mvp_multivalue_args { qw(phases skips) }
+sub mvp_aliases { { phase => 'phases', skip => 'skips' } }
 
 around BUILDARGS => sub
 {
@@ -89,8 +97,13 @@ sub after_build
         foreach my $prereq (keys %{ $prereqs->{$phase}{requires} // {} })
         {
             next if $prereq eq 'perl';
-            $self->log_debug("checking $prereq");
 
+            if ($self->skip_module(sub { $_ eq $prereq })) {
+                $self->log_debug("skipping $prereq");
+                next;
+            }
+
+            $self->log_debug("checking $prereq");
             my $added_in = Module::CoreList->first_release($prereq);
 
             if (not defined $added_in)
@@ -157,8 +170,9 @@ sub _is_dual
     return 1 if defined $upstream and ($upstream eq 'cpan' or $upstream eq 'first-come');
 
     # if upstream=blead or =undef, we can't be sure if it's actually dual or
-    # not, so for now we'll have to ask the index and hope that there's been a
-    # release to cpan since the last stable perl release.
+    # not, so for now we'll have to ask the index and hope that the
+    # 'no_index' entries in the last perl release were complete.
+    # TODO: keep checking Module::CoreList for fixes.
     my $dist_name = $self->_indexed_dist($module);
     $self->log_debug($module . ' is indexed in the ' . ($dist_name // 'undef') . ' dist');
     return 0 if not defined $dist_name or $dist_name eq 'perl';
@@ -200,7 +214,7 @@ Dist::Zilla::Plugin::OnlyCorePrereqs - Check that no prerequisites are declared
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -228,7 +242,7 @@ If the check fails, the build is aborted.
 =item * C<phase>
 
 Indicates a phase to check against. Can be provided more than once; defaults
-to C<runtime> and C<test>.  (See L<Dist::Zilla::Plugin::Prereqs> for more
+to C<configure>, C<build>, C<runtime>, C<test>.  (See L<Dist::Zilla::Plugin::Prereqs> for more
 information about phases.)
 
 Remember that you can use different settings for different phases by employing
@@ -283,6 +297,10 @@ to L<Module::CoreList>).
 L<Test::More> that shipped with that version of perl was only 0.72,
 but not fail if C<check_dual_life_versions = 0>.
 
+=item * C<skip>
+
+The name of a module to exempt from checking. Can be used more than once.
+
 =back
 
 =head1 SUPPORT
